const isDevelopment = process.env.NODE_ENV === 'development';
async function loaderWithMiddleware(params, middlewareOptions, middlewareStack) {
    const { logger } = params.context;
    logger.debug('middlewares [%j]', middlewareStack);
    const loaderData = middlewareOptions ? middlewareOptions : {};
    const executeMiddlewares = async (index) => {
        if (index < middlewareStack.length) {
            const middleware = middlewareStack[index];
            const start = process.hrtime(); // Get start time
            if (isDevelopment) {
                console.log(`[[Middleware ${middleware.name}]] starts to run`); // Log start
            }
            await middleware.func(params, loaderData, async () => await executeMiddlewares(index + 1));
            if (isDevelopment) {
                const end = process.hrtime(start); // Get end time
                const elapsedTime = (end[0] * 1e9 + end[1]) / 1e6; // Convert to milliseconds
                console.log(`[[Middleware ${middleware.name}]] took ${elapsedTime} ms`); // Log time taken
            }
        }
    };
    await executeMiddlewares(0); // Start middleware execution from the first one
    return loaderData;
}export{loaderWithMiddleware};